View source: R/location_code_to.R
| location_code_to_iso3 | R Documentation |
Returns the ISO 3166-1 alpha-3 country code for each location code.
Currently all Norwegian location codes map to "nor".
location_code_to_iso3(x)
x |
A character vector of location codes, or a data.table / data.frame
containing a column named |
A character vector the same length as x (or with as many elements
as there are rows in x when x is a data.table), containing the
corresponding ISO 3166-1 alpha-3 country code (always "nor").
csdata::location_code_to_iso3(c("nation_nor", "county_nor03", "municip_nor0301"))
library(data.table)
dt <- data.table(location_code = c("nation_nor", "county_nor03"))
csdata::location_code_to_iso3(dt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.