View source: R/nor_locations_hierarchy.R
| nor_locations_hierarchy_from_to | R Documentation |
Returns a mapping between two geographic levels in Norway. Both from and
to accept character vectors, in which case all requested combinations are
returned combined into a single data.table.
nor_locations_hierarchy_from_to(
from,
to,
include_to_name = FALSE,
border = csdata::config$border_nor
)
from |
Character vector. The source geographic granularity. One or more
of: |
to |
Character vector. The target geographic granularity. Same valid
values as |
include_to_name |
Logical. If |
border |
Integer. The geographic border year. Valid values: |
A data.table with columns:
Location code at the from granularity level.
Location code at the to granularity level.
Name of the to location (only present when
include_to_name = TRUE).
csdata::nor_locations_hierarchy_from_to(from = "wardoslo", to = "county")
csdata::nor_locations_hierarchy_from_to(from = "municip", to = "baregion")
csdata::nor_locations_hierarchy_from_to(
from = c("municip", "county"),
to = "georegion",
include_to_name = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.