View source: R/nor_locations_names.R
| nor_locations_names | R Documentation |
Returns a data.table of all Norwegian geographic units with their location codes, display names, and presentation metadata. Coverage includes nation, counties, municipalities, city districts (Oslo, Bergen, Stavanger, Trondheim), BA-regions, and lab regions.
nor_locations_names(border = csdata::config$border_nor)
border |
Integer. The geographic border year determining which
administrative boundaries are used. Valid values: |
A data.table with one row per geographic unit and the columns:
Location code (e.g. "nation_nor", "county_nor03").
Full location name.
Abbreviated name: 1-letter for nation and county, shorter display name for Oslo and Bergen city districts.
Location name with a parenthetical description of geographic level (Norwegian Bokmal).
Name suitable for use in file names, retaining Norwegian characters.
Name suitable for use in file names, with Norwegian characters replaced by ASCII equivalents.
Integer giving the preferred presentation order.
Geographic granularity: one of "nation",
"georegion", "mtregion", "county", "municip", "baregion",
"wardoslo", "wardbergen", "wardstavanger", "wardtrondheim",
"extrawardoslo", "lab".
https://no.wikipedia.org/wiki/Liste_over_norske_kommunenummer
d <- nor_locations_names()
head(d)
d[granularity_geo == "county"]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.