View source: R/nor_locations_redistricting.R
| nor_locations_redistricting | R Documentation |
Returns a data.table of weighting factors used to convert historical data recorded under old administrative boundaries to the 2024 borders. Each row maps an original location code (as of a given calendar year) to the current location code, with a proportional weighting.
nor_locations_redistricting(border = csdata::config$border_nor)
border |
Integer. The target geographic border year. Valid values:
|
A data.table with columns:
Location code under the target border year.
Location code as it existed in calyear.
The calendar year to which location_code_original
applies.
Proportional weight to apply when aggregating from the
original location to the current location (values sum to 1 within each
location_code_original / calyear group).
Geographic granularity: one of "nation",
"county", "municip", "wardbergen", "wardoslo",
"wardstavanger", "wardtrondheim", "missingwardbergen",
"missingwardoslo", "missingwardstavanger", "missingwardtrondheim",
"notmainlandcounty", "notmainlandmunicip", "missingcounty".
Statistics Norway (SSB) municipal reform documentation.
d <- csdata::nor_locations_redistricting()
head(d)
d[calyear == 2019 & granularity_geo == "municip"]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.