set_config: Set package configuration options

View source: R/config_aa_environments.r

set_configR Documentation

Set package configuration options

Description

Updates one or more variables in the config environment. Call this at the start of a script to change the default border year used by all data-returning functions.

Usage

set_config(border_nor = NULL)

Arguments

border_nor

Integer. The Norwegian geographic border year to use as the default. Valid values: 2024. Pass NULL to leave unchanged.

Value

NULL, invisibly. Called for the side effect of updating config.

Examples

old <- csdata::config$border_nor
csdata::set_config(border_nor = 2024)
csdata::config$border_nor  # 2024
csdata::set_config(border_nor = old)  # restore

csdata documentation built on July 3, 2026, 1:07 a.m.