View source: R/config_aa_environments.r
| set_config | R Documentation |
Updates one or more variables in the config environment. Call this at the start of a script to change the default border year used by all data-returning functions.
set_config(border_nor = NULL)
border_nor |
Integer. The Norwegian geographic border year to use as
the default. Valid values: |
NULL, invisibly. Called for the side effect of updating config.
old <- csdata::config$border_nor
csdata::set_config(border_nor = 2024)
csdata::config$border_nor # 2024
csdata::set_config(border_nor = old) # restore
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.